/**
 * (c) Meta Platforms, Inc. and affiliates. Confidential and proprietary.
 */

//==============================================================================
// Welcome to scripting in Spark AR Studio! Helpful links:
//
// Scripting Basics - https://fb.me/spark-scripting-basics
// Reactive Programming - https://fb.me/spark-reactive-programming
// Scripting Object Reference - https://fb.me/spark-scripting-reference
// Changelogs - https://fb.me/spark-changelog
//
// Spark AR Studio extension for VS Code - https://fb.me/spark-vscode-plugin
//
// For projects created with v87 onwards, JavaScript is always executed in strict mode.
//==============================================================================

// How to load in modules
import Scene from 'Scene';
import Diagnostics from 'Diagnostics';
import Reactive from 'Reactive';
import Blocks from 'Blocks';
import Persistence from 'Persistence';
import TouchGestures from 'TouchGestures';

(async function () {  // Enables async/await in JS [part 1]
    const [text2D, rhino] = await Promise.all([
        Scene.root.findFirst('2dText0'),
        Scene.root.findFirst('Rhinoad'),
    ]);

    let state = {
        count: 0
        // Add additional props to persist here
    };

    let storageLocation = Persistence.block;

    // At Block instantiation time
    try {
        let restoredState = await storageLocation.get("state");
        if (restoredState !== null) {
            state = restoredState;
        } else {
            Diagnostics.log('Failed to find stored data');
        }
    } catch (err) {
        // Handle failed promise from StorageLocation.get
        Diagnostics.error(err);
    }
    text2D.text = 'You tapped the Rhino ' + state.count + ' times in total!';

    TouchGestures.onTap(rhino).subscribe(() => {
        state.count += 1;
        text2D.text = 'You tapped the Rhino ' + state.count + ' times in total!';
        Diagnostics.log('Tapped!');

        storageLocation.set("state", state);

    });

})(); // Enables async/await in JS [part 2]
