/**
 * (c) Meta Platforms, Inc. and affiliates. Confidential and proprietary.
 */

//==============================================================================
// Welcome to scripting in Spark AR Studio! Helpful links:
//
// Scripting Basics - https://fb.me/spark-scripting-basics
// Reactive Programming - https://fb.me/spark-reactive-programming
// Scripting Object Reference - https://fb.me/spark-scripting-reference
// Changelogs - https://fb.me/spark-changelog
//
// Spark AR Studio extension for VS Code - https://fb.me/spark-vscode-plugin
//
// For projects created with v87 onwards, JavaScript is always executed in strict mode.
//==============================================================================

// How to load in modules
import Scene from 'Scene';
import TouchGestures from 'TouchGestures';
import Blocks from 'Blocks';
import Persistence from 'Persistence';

(async function () {  // Enables async/await in JS [part 1]

    // Locate the planes in the scene and the focal distance
    const [plane0, plane1, focalDistance] = await Promise.all([
        Scene.root.findFirst('plane0'),
        Scene.root.findFirst('plane1'),
        Scene.root.findFirst('Focal Distance'),
    ]);

    let block0;

    // Create the block with BlockStorage when plane0 is tapped
    TouchGestures.onTap(plane0).subscribe(() => {
        if (!block0) {
            Blocks
                .instantiate('block0', {}, { storage: Persistence.localBlockStorage('myStorage') })
                .then(function (res) {
                    block0 = res;
                    return focalDistance.addChild(res);
                },
                );
        }
    });

    // Destroy the block when plane1 is tapped
    TouchGestures.onTap(plane1).subscribe(() => {
        if (block0) {
            Scene.destroy(block0).then(() => { block0 = null; });
        }
    });

})(); // Enables async/await in JS [part 2]
